@@ -1,10 +1,11 @@
 /*
  * EFI Boot Guard
  *
- * Copyright (c) Siemens AG, 2017
+ * Copyright (c) Siemens AG, 2017-2023
  *
  * Authors:
  *  Andreas Reichel <andreas.reichel.ext@siemens.com>
+ *  Felix Moessbauer <felix.moessbauer@siemens.com>
  *
  * This work is licensed under the terms of the GNU GPL, version 2.  See
  * the COPYING file in the top-level directory.
@@ -16,6 +17,9 @@
 #include "ebgenv.h"
 #include "uservars.h"
 
+/* global EBG options */
+ebgenv_opts_t ebgenv_opts;
+
 /* UEFI uses 16-bit wide unicode strings.
  * However, wchar_t support functions are fixed to 32-bit wide
  * characters in glibc. This code is compiled with
@@ -56,9 +60,40 @@ char16_t *str8to16(char16_t *buffer, const char *src)
 	return tmp;
 }
 
-void ebg_beverbose(ebgenv_t __attribute__((unused)) *e, bool v)
+int ebg_set_opt_bool(ebg_opt_t opt, bool value)
 {
-	bgenv_be_verbose(v);
+	switch (opt) {
+	case EBG_OPT_PROBE_ALL_DEVICES:
+		ebgenv_opts.search_all_devices = value;
+		break;
+	case EBG_OPT_VERBOSE:
+		ebgenv_opts.verbose = value;
+		bgenv_be_verbose(value);
+		break;
+	default:
+		return EINVAL;
+	}
+	return 0;
+}
+
+int ebg_get_opt_bool(ebg_opt_t opt, bool *value)
+{
+	switch (opt) {
+	case EBG_OPT_PROBE_ALL_DEVICES:
+		*value = ebgenv_opts.search_all_devices;
+		break;
+	case EBG_OPT_VERBOSE:
+		*value = ebgenv_opts.verbose;
+		break;
+	default:
+		return EINVAL;
+	}
+	return 0;
+}
+
+void ebg_beverbose(ebgenv_t __attribute__((unused)) * e, bool v)
+{
+	ebg_set_opt_bool(EBG_OPT_VERBOSE, v);
 }
 
 int ebg_env_create_new(ebgenv_t *e)
@@ -202,7 +237,7 @@ int ebg_env_setglobalstate(ebgenv_t *e, uint16_t ustate)
 		}
 		if (env->data->ustate != ustate) {
 			env->data->ustate = ustate;
-			env->data->crc32 = crc32(0, (Bytef *)env->data,
+			env->data->crc32 = bgenv_crc32(0, env->data,
 				sizeof(BG_ENVDATA) - sizeof(env->data->crc32));
 			if (!bgenv_write(env)) {
 				bgenv_close(env);
@@ -228,8 +263,8 @@ int ebg_env_close(ebgenv_t *e)
 
 	/* recalculate checksum */
 	env_current->data->crc32 =
-	    crc32(0, (Bytef *)env_current->data,
-		  sizeof(BG_ENVDATA) - sizeof(env_current->data->crc32));
+	    bgenv_crc32(0, env_current->data,
+			sizeof(BG_ENVDATA) - sizeof(env_current->data->crc32));
 	/* save */
 	if (!bgenv_write(env_current)) {
 		res = EIO;
