@@ -20,7 +20,7 @@
 #include "test-interface.h"
 #include "ebgpart.h"
 
-bool bgenv_verbosity = false;
+extern ebgenv_opts_t ebgenv_opts;
 
 EBGENVKEY bgenv_str2enum(char *key)
 {
@@ -47,21 +47,20 @@ EBGENVKEY bgenv_str2enum(char *key)
 
 void bgenv_be_verbose(bool v)
 {
-	bgenv_verbosity = v;
 	ebgpart_beverbose(v);
 }
 
 static void clear_envdata(BG_ENVDATA *data)
 {
 	memset(data, 0, sizeof(BG_ENVDATA));
-	data->crc32 = crc32(0, (Bytef *)data,
-			    sizeof(BG_ENVDATA) - sizeof(data->crc32));
+	data->crc32 = bgenv_crc32(0, data,
+				  sizeof(BG_ENVDATA) - sizeof(data->crc32));
 }
 
 bool validate_envdata(BG_ENVDATA *data)
 {
-	uint32_t sum = crc32(0, (Bytef *)data,
-			     sizeof(BG_ENVDATA) - sizeof(data->crc32));
+	uint32_t sum = bgenv_crc32(0, data,
+				   sizeof(BG_ENVDATA) - sizeof(data->crc32));
 
 	if (data->crc32 != sum) {
 		VERBOSE(stderr, "Invalid CRC32!\n");
@@ -106,7 +105,7 @@ bool read_env(CONFIG_PART *part, BG_ENVDATA *env)
 		}
 		result = false;
 	}
-	if (close_config_file(config)) {
+	if (fclose(config)) {
 		VERBOSE(stderr,
 			"Error closing environment file after reading.\n");
 	};
@@ -151,7 +150,7 @@ bool write_env(CONFIG_PART *part, BG_ENVDATA *env)
 			part->devpath);
 		result = false;
 	}
-	if (close_config_file(config)) {
+	if (fclose(config)) {
 		VERBOSE(stderr,
 			"Error closing environment file after writing.\n");
 		result = false;
@@ -174,7 +173,8 @@ bool bgenv_init(void)
 		return true;
 	}
 	/* enumerate all config partitions */
-	if (!probe_config_partitions(config_parts)) {
+	if (!probe_config_partitions(config_parts,
+				     ebgenv_opts.search_all_devices)) {
 		VERBOSE(stderr, "Error finding config partitions.\n");
 		return false;
 	}
