@@ -28,7 +28,6 @@
 #include <sys/file.h>
 #include <sys/mount.h>
 #include "config.h"
-#include <zlib.h>
 #include "envdata.h"
 #include "ebgenv.h"
 #include <uchar.h>
@@ -43,11 +42,10 @@
 
 #define DEFAULT_TIMEOUT_SEC 30
 
-extern bool bgenv_verbosity;
+extern ebgenv_opts_t ebgenv_opts;
 
-#define VERBOSE(o, ...)                                                       \
-	if (bgenv_verbosity)                                                    \
-	fprintf(o, __VA_ARGS__)
+#define VERBOSE(o, ...)                                                        \
+	if (ebgenv_opts.verbose) fprintf(o, __VA_ARGS__)
 
 typedef enum {
 	EBGENV_KERNELFILE,
@@ -80,6 +78,8 @@ extern void bgenv_be_verbose(bool v);
 extern char *str16to8(char *buffer, const char16_t *src);
 extern char16_t *str8to16(char16_t *buffer, const char *src);
 
+extern uint32_t bgenv_crc32(uint32_t, const void *, size_t);
+
 extern bool bgenv_init(void);
 extern void bgenv_finalize(void);
 extern BGENV *bgenv_open_by_index(uint32_t index);
