@@ -17,4 +17,4 @@
 #include <stdbool.h>
 #include "env_api.h"
 
-bool probe_config_partitions(CONFIG_PART *cfgpart);
+bool probe_config_partitions(CONFIG_PART *cfgpart, bool search_all_devices);
