@@ -115,6 +115,7 @@ newaction_nomem:
 static void journal_process_action(BGENV *env, struct env_action *action)
 {
 	ebgenv_t e;
+	memset(&e, 0, sizeof(ebgenv_t));
 
 	switch (action->task) {
 	case ENV_TASK_SET:
@@ -322,8 +323,9 @@ static void update_environment(BGENV *env, bool verbosity)
 		journal_free_action(action);
 	}
 
-	env->data->crc32 = crc32(0, (const Bytef *)env->data,
-				 sizeof(BG_ENVDATA) - sizeof(env->data->crc32));
+	env->data->crc32 =
+		bgenv_crc32(0, env->data,
+			    sizeof(BG_ENVDATA) - sizeof(env->data->crc32));
 
 }
 
@@ -417,6 +419,12 @@ error_t bg_setenv(int argc, char **argv)
 	}
 
 	/* not in file mode */
+	if (arguments.common.search_all_devices) {
+		ebg_set_opt_bool(EBG_OPT_PROBE_ALL_DEVICES, true);
+	}
+	if (arguments.common.verbosity) {
+		ebg_set_opt_bool(EBG_OPT_VERBOSE, true);
+	}
 	if (!bgenv_init()) {
 		fprintf(stderr, "Error initializing FAT environment.\n");
 		return 1;
