@@ -18,6 +18,7 @@
 
 #include "ebgpart.h"
 #include <sys/sysmacros.h>
+#include "fat.h"
 
 static PedDevice *first_device = NULL;
 static PedDisk g_ped_dummy_disk;
@@ -43,7 +44,7 @@ static void add_block_dev(PedDevice *dev)
 	d->next = dev;
 }
 
-static char *GUID_to_str(uint8_t *g)
+static char *GUID_to_str(const uint8_t *g)
 {
 	(void)snprintf(buffer, 37,
 		       "%02X%02X%02X%02X-%02X%02X-%02X%02X-%02X%02X-"
@@ -53,99 +54,98 @@ static char *GUID_to_str(uint8_t *g)
 	return buffer;
 }
 
-static char *type_to_name(char t)
+static EbgFileSystemType type_to_fstype(char t)
 {
 	switch (t) {
 	case MBR_TYPE_FAT12:
-		return "fat12";
+		return FS_TYPE_FAT12;
 	case MBR_TYPE_FAT16A:
 	case MBR_TYPE_FAT16:
 	case MBR_TYPE_FAT16_LBA:
-		return "fat16";
+		return FS_TYPE_FAT16;
 	case MBR_TYPE_FAT32:
 	case MBR_TYPE_FAT32_LBA:
-		return "fat32";
+		return FS_TYPE_FAT32;
 	case MBR_TYPE_EXTENDED_LBA:
 	case MBR_TYPE_EXTENDED:
-		return "extended";
+		return FS_TYPE_EXTENDED;
 	}
-	return "not supported";
+	return FS_TYPE_UNKNOWN;
 }
 
-static bool check_GPT_FAT_entry(int fd, struct EFIpartitionentry *e,
-				PedFileSystemType *pfst, uint32_t i)
+/**
+ * @brief Determines the FAT bit size of a disk or partition.
+ *
+ * @param fd        File descriptor to inspect.
+ * @param e         A pointer to the EFI partition entry.
+ *
+ * @return >0: FAT bit size of the disk or partition
+ *         =0: non-FAT partition
+ *         <0: I/O error
+ **/
+static int check_GPT_FAT_entry(int fd, const struct EFIpartitionentry *e)
 {
 	char *guid_str = GUID_to_str(e->type_GUID);
 	if (strcmp(GPT_PARTITION_GUID_FAT_NTFS, guid_str) != 0 &&
 	    strcmp(GPT_PARTITION_GUID_ESP, guid_str) != 0) {
-		if (asprintf(&pfst->name, "%s", "not supported") == -1) {
-			goto error_asprintf;
-		}
 		VERBOSE(stderr, "GPT entry has unsupported GUID: %s\n",
 			guid_str);
-		return true;
+		return 0;
 	}
-	VERBOSE(stdout, "GPT Partition #%u is FAT/NTFS.\n", i);
+	VERBOSE(stdout, "GPT Partition has a FAT/NTFS GUID\n");
+
 	/* Save current file offset */
 	off64_t curr = lseek64(fd, 0, SEEK_CUR);
 	if (curr == -1) {
 		VERBOSE(stderr, "Error getting current seek position: %s\n",
 			strerror(errno));
-		return false;
+		return -1;
 	}
-	/* Look if it is a FAT12 or FAT16 */
-	off64_t dest = (off64_t)e->start_LBA * LB_SIZE + 0x36;
-	if (lseek64(fd, dest, SEEK_SET) == -1) {
-		VERBOSE(stderr, "Error seeking FAT12/16 Id String: %s\n",
+
+	/* seek to partition start */
+	off64_t offset_start = (off64_t)e->start_LBA * LB_SIZE;
+	if (lseek64(fd, offset_start, SEEK_SET) == -1) {
+		VERBOSE(stderr, "Error seeking to partition start: %s\n",
 			strerror(errno));
-		return false;
+		return -1;
 	}
-	char FAT_id[9];
-	if (read(fd, FAT_id, 8) != 8) {
-		VERBOSE(stderr, "Error reading FAT12/16 Id String: %s\n",
+
+	/* read FAT header */
+	struct fat_boot_sector header;
+	if (read(fd, &header, sizeof(header)) != sizeof(header)) {
+		VERBOSE(stderr, "Error reading FAT header: %s\n",
 			strerror(errno));
-		return false;
-	};
-	FAT_id[8] = 0;
-	if (strcmp(FAT_id, "FAT12   ") != 0 &&
-	    strcmp(FAT_id, "FAT16   ") != 0) {
-		/* No FAT12/16 so read ID field for FAT32 */
-		dest = (off64_t)e->start_LBA * LB_SIZE + 0x52;
-		if (lseek64(fd, dest, SEEK_SET) == -1) {
-			VERBOSE(stderr, "Error seeking FAT32 Id String: %s\n",
-				strerror(errno));
-			return false;
-		}
-		if (read(fd, FAT_id, 8) != 8) {
-			VERBOSE(stderr, "Error reading FAT32 Id String: %s\n",
-				strerror(errno));
-			return false;
-		}
+		return -1;
 	}
-	if (strcmp(FAT_id, "FAT12   ") == 0) {
-		if (asprintf(&pfst->name, "%s", "fat12") == -1) {
-			goto error_asprintf;
-		}
-	} else if (strcmp(FAT_id, "FAT16   ") == 0) {
-		if (asprintf(&pfst->name, "%s", "fat16") == -1) {
-			goto error_asprintf;
-		}
-	} else {
-		if (asprintf(&pfst->name, "%s", "fat32") == -1) {
-			goto error_asprintf;
-		}
-	}
-	VERBOSE(stdout, "GPT Partition #%u is %s.\n", i, pfst->name);
+
+	/* restore pos */
 	if (lseek64(fd, curr, SEEK_SET) == -1) {
 		VERBOSE(stderr, "Error restoring seek position (%s)",
 			strerror(errno));
-		return false;
+		return -1;
 	}
-	return true;
+	return determine_FAT_bits(&header);
+}
 
-error_asprintf:
-	VERBOSE(stderr, "Error in asprintf - possibly out of memory.\n");
-	return false;
+static inline EbgFileSystemType fat_size_to_fs_type(int fat_size)
+{
+	switch (fat_size) {
+	case 0:
+		VERBOSE(stderr, "Not a FAT partition\n");
+		return FS_TYPE_UNKNOWN;
+	case 12:
+		VERBOSE(stdout, "Partition is fat12\n");
+		return FS_TYPE_FAT12;
+	case 16:
+		VERBOSE(stdout, "Partition is fat16\n");
+		return FS_TYPE_FAT16;
+	case 32:
+		VERBOSE(stdout, "Partition is fat32\n");
+		return FS_TYPE_FAT32;
+	default:
+		VERBOSE(stderr, "Error: Invalid FAT size %d\n", fat_size);
+		return FS_TYPE_UNKNOWN;
+	}
 }
 
 static void read_GPT_entries(int fd, uint64_t table_LBA, uint32_t num,
@@ -154,7 +154,6 @@ static void read_GPT_entries(int fd, uint64_t table_LBA, uint32_t num,
 	off64_t offset;
 	struct EFIpartitionentry e;
 	PedPartition *tmpp;
-	PedFileSystemType *pfst = NULL;
 
 	offset = LB_SIZE * table_LBA;
 	if (lseek64(fd, offset, SEEK_SET) != offset) {
@@ -175,28 +174,22 @@ static void read_GPT_entries(int fd, uint64_t table_LBA, uint32_t num,
 			return;
 		}
 		VERBOSE(stdout, "%u: %s\n", i, GUID_to_str(e.type_GUID));
-		pfst = calloc(sizeof(PedFileSystemType), 1);
-		if (!pfst) {
-			VERBOSE(stderr, "Out of memory\n");
-			return;
-		}
 
 		tmpp = calloc(sizeof(PedPartition), 1);
 		if (!tmpp) {
 			VERBOSE(stderr, "Out of memory\n");
-			free(pfst);
 			return;
 		}
 		tmpp->num = i + 1;
-		tmpp->fs_type = pfst;
 
-		if (!check_GPT_FAT_entry(fd, &e, pfst, i)) {
-			free(pfst->name);
-			free(pfst);
+		int result = check_GPT_FAT_entry(fd, &e);
+		if (result < 0) {
+			VERBOSE(stderr, "%u: I/O error, skipping device\n", i);
 			free(tmpp);
 			dev->part_list = NULL;
 			continue;
 		}
+		tmpp->fs_type = fat_size_to_fs_type(result);
 
 		*list_end = tmpp;
 		list_end = &((*list_end)->next);
@@ -208,7 +201,6 @@ static void scanLogicalVolumes(int fd, off64_t extended_start_LBA,
 			       PedPartition *partition, int lognum)
 {
 	struct Masterbootrecord next_ebr;
-	PedFileSystemType *pfst = NULL;
 
 	off64_t offset = extended_start_LBA + ebr->parttable[i].start_LBA;
 	if (extended_start_LBA == 0) {
@@ -246,21 +238,13 @@ static void scanLogicalVolumes(int fd, off64_t extended_start_LBA,
 		if (!partition->next) {
 			goto scl_out_of_mem;
 		}
-		pfst = calloc(sizeof(PedFileSystemType), 1);
-		if (!pfst) {
-			goto scl_out_of_mem;
-		}
-		if (asprintf(&pfst->name, "%s", type_to_name(t)) == -1) {
-			goto scl_out_of_mem;
-		};
 		partition = partition->next;
 		partition->num = lognum;
-		partition->fs_type = pfst;
+		partition->fs_type = type_to_fstype(t);
 	}
 	return;
 scl_out_of_mem:
 	VERBOSE(stderr, "Out of memory\n");
-	free(pfst);
 	free(partition->next);
 }
 
@@ -329,26 +313,18 @@ static bool check_partition_table(PedDevice *dev)
 					 efihdr.partitions, dev);
 			break;
 		}
-		PedFileSystemType *pfst = calloc(sizeof(PedFileSystemType), 1);
-		if (!pfst) {
-			goto cpt_out_of_mem;
-		}
-
 		tmp = calloc(sizeof(PedPartition), 1);
 		if (!tmp) {
 			goto cpt_out_of_mem;
 		}
 
 		tmp->num = i + 1;
-		tmp->fs_type = pfst;
 
 		*list_end = tmp;
 		list_end = &((*list_end)->next);
 
 		if (t == MBR_TYPE_EXTENDED || t == MBR_TYPE_EXTENDED_LBA) {
-			if (asprintf(&pfst->name, "%s", "extended") == -1) {
-				goto cpt_out_of_mem;
-			}
+			tmp->fs_type = FS_TYPE_EXTENDED;
 			scanLogicalVolumes(fd, 0, &mbr, i, tmp, 5);
 			/* Could be we still have MBR entries after
 			 * logical volumes */
@@ -356,15 +332,12 @@ static bool check_partition_table(PedDevice *dev)
 				list_end = &((*list_end)->next);
 			}
 		} else {
-			if (asprintf(&pfst->name, "%s", type_to_name(t)) == -1) {
-				goto cpt_out_of_mem;
-			}
+			tmp->fs_type = type_to_fstype(t);
 		}
 		continue;
 	cpt_out_of_mem:
 		close(fd);
 		VERBOSE(stderr, "Out of mem while checking partition table\n.");
-		free(pfst);
 		free(tmp);
 		return false;
 	}
@@ -385,9 +358,8 @@ static int scan_devdir(unsigned int fmajor, unsigned int fminor, char *fullname,
 		VERBOSE(stderr, "Failed to open %s\n", DEVDIR);
 		return result;
 	}
-	struct dirent *devfile;
-	do {
-		devfile = readdir(devdir);
+	while (true) {
+		struct dirent *devfile = readdir(devdir);
 		if (!devfile) {
 			break;
 		}
@@ -404,7 +376,7 @@ static int scan_devdir(unsigned int fmajor, unsigned int fminor, char *fullname,
 			result = 0;
 			break;
 		}
-	} while (devfile);
+	}
 	closedir(devdir);
 
 	return result;
@@ -428,9 +400,9 @@ static int get_major_minor(char *filename, unsigned int *major, unsigned int *mi
 	return 0;
 }
 
-void ped_device_probe_all(void)
+void ped_device_probe_all(char *rootdev)
 {
-	struct dirent *sysblockfile;
+	struct dirent *sysblockfile = NULL;
 	char fullname[DEV_FILENAME_LEN+16];
 
 	DIR *sysblockdir = opendir(SYSBLOCKDIR);
@@ -441,16 +413,21 @@ void ped_device_probe_all(void)
 
 	/* get all files from sysblockdir */
 	do {
-		sysblockfile = readdir(sysblockdir);
-		if (!sysblockfile) {
-			break;
-		}
-		if (strcmp(sysblockfile->d_name, ".") == 0 ||
-		    strcmp(sysblockfile->d_name, "..") == 0) {
-			continue;
+		char *devname = rootdev;
+		if (!rootdev) {
+			sysblockfile = readdir(sysblockdir);
+			if (!sysblockfile) {
+				break;
+			}
+			if (strcmp(sysblockfile->d_name, ".") == 0 ||
+			    strcmp(sysblockfile->d_name, "..") == 0) {
+				continue;
+			}
+			devname = sysblockfile->d_name;
 		}
+
 		(void)snprintf(fullname, sizeof(fullname), "/sys/block/%s/dev",
-			 sysblockfile->d_name);
+			       devname);
 		/* Get major and minor revision from /sys/block/sdX/dev */
 		unsigned int fmajor, fminor;
 		if (get_major_minor(fullname, &fmajor, &fminor) < 0) {
@@ -461,7 +438,7 @@ void ped_device_probe_all(void)
 			fmajor, fminor, fullname);
 		/* Check if this file is really in the dev directory */
 		(void)snprintf(fullname, sizeof(fullname), "%s/%s", DEVDIR,
-			 sysblockfile->d_name);
+			       devname);
 		struct stat statbuf;
 		if (stat(fullname, &statbuf) == -1) {
 			/* Node with same name not found in /dev, thus search
@@ -497,15 +474,8 @@ pedprobe_error:
 	closedir(sysblockdir);
 }
 
-static void ped_partition_destroy(PedPartition *p)
+static inline void ped_partition_destroy(PedPartition *p)
 {
-	if (!p) {
-		return;
-	}
-	if (p->fs_type) {
-		free(p->fs_type->name);
-		free(p->fs_type);
-	}
 	free(p);
 }
 
